@@ -54,6 +54,8 @@ barp<-function(height,width=0.4,names.arg=NULL,legend.lab=NULL,legend.pos=NULL,
  if(is.null(height.at)) {
   if(ylog) height.at<-axTicks(2,log=TRUE)
   else height.at<-pretty(ylim)
+  if(max(height.at) > max(height,na.rm=TRUE))
+   height.at<-height.at[-length(height.at)]
  }
  if(is.null(height.lab)) height.lab<-height.at
  if(staxy) {
